@@ -1,3 +1,4 @@
+import json
 import os
 import yaml
 import logging
@@ -17,8 +18,9 @@ class network3_perseus():
         self.get_file_from_hedera()
         self.add_file_to_hedera()
         self.pre_change=self.capture_pre_state()
-        self.push_config(self.yaml_contents)
+        self.push_config()
         self.post_change=self.capture_post_state()
+        self.add_transaction()
 
     def get_file_id_from_dragonglass(self):
         url = f"https://api-testnet.dragonglass.me/hedera/api/accounts/{ INTENTID }/files"
@@ -30,7 +32,6 @@ class network3_perseus():
         response = requests.request("GET", url, headers=headers, data = payload, verify=False)
         json_response = response.json()
         self.fileId=json_response['data'][0]['fileID']
-        print(self.fileId)
 
     def get_file_from_hedera(self):
         client = Client.forTestnet()
@@ -64,11 +65,10 @@ class network3_perseus():
         info = query.execute(self.client)
         print("File size according to `FileInfoQuery`: ", info.size)
 
-    def push_config(self,yaml_contents):
+    def push_config(self):
         env = Environment(loader=PackageLoader("network3_perseus", "templates"))
         intended_config_template = env.get_template('intended_config.j2')
-        print(self.yaml_contents)
-        rendered_intended_config = intended_config_template.render(self.yaml_contents)
+        rendered_intended_config = intended_config_template.render(self.yaml_contents[0])
         subprocess.run(["python", "cli_configure.py", rendered_intended_config])
 
     def add_file_to_hedera(self):
@@ -86,16 +86,31 @@ class network3_perseus():
         print("file: ",  self.fileId.toString())
         print("File size according to `FileInfoQuery`: ", info.size)
         
-    def append_file_to_hedera(self, interface):
+    def append_file_to_hedera(self, config):
         tran = (FileAppendTransaction()
                 .setFileId(self.fileId)
-                .setContents(interface)
+                .setContents(config)
                 .setMaxChunks(500)
                 .setMaxTransactionFee(Hbar(2))
                 .freezeWith(self.client))
         resp = tran.execute(self.client)
         self.receipt = resp.getReceipt(self.client)
 
+    def add_transaction(self):
+        url = f"https://api-testnet.dragonglass.me/hedera/api/accounts/{ OPERATOR_ID }/files"
+        payload = {}
+        headers = {
+            'X-API-KEY': f'{ APIKEY }',
+            'accept': 'application/json'
+        }
+        response = requests.request("GET", url, headers=headers, data = payload, verify=False)
+        json_response = response.json()
+        print(json_response)
+        self.transactionID=json_response['data'][0]['transactionID']
+        self.append_file_to_hedera(f"Configuration Transaction ID: { self.transactionID }")
+        self.transactionDate=json_response['data'][0]['transactionDate']
+        self.append_file_to_hedera(f"Configuration Transaction Date: { self.transactionDate }")
+
 def cli():
     invoke_class = network3_perseus()
     invoke_class.configure_device()
